%bcond_without ocaml

%global rel_ver %(echo %{version} | awk -F. '{print $1"."$2}')
%if %{with ocaml}
# The OCaml runtime system does not provide this symbol
%global __ocaml_requires_opts -x Stdlib__Callback
%endif

Summary:        NBD client library in userspace
Name:           libnbd
Version:        1.17.3
Release:        4%{?dist}
License:        LGPL-2.0-or-later AND BSD-3-Clause
URL:            https://gitlab.com/nbdkit/libnbd
Source0:        http://libguestfs.org/download/libnbd/%{rel_ver}-development/%{name}-%{version}.tar.gz
Patch0001:      0001-generator-Handle-.-configure-disable-rust.patch
Patch0002:      fix-CVE-2023-5215.patch

BuildRequires:  gcc make gcc-c++
BuildRequires:  /usr/bin/pod2man gnutls-devel libxml2-devel glib2-devel
BuildRequires:  fuse3, fuse3-devel liburing-devel >= 2.2
BuildRequires:  python3-devel bash-completion util-linux
BuildRequires:  coreutils gnutls-utils iproute jq
%if %{with ocaml}
BuildRequires:  ocaml
BuildRequires:  ocaml-findlib-devel
BuildRequires:  ocaml-ocamldoc
%endif


%description
NBD — Network Block Device — is a protocol for accessing Block Devices
(hard disks and disk-like things) over a Network.  This is the NBD
client library in userspace, a simple library for writing NBD clients.

The key features are:

- Synchronous API for ease of use.
- Asynchronous API for writing non-blocking, multithreaded clients.
- You can mix both APIs freely.
- High performance.
- Minimal dependencies for the basic library.
- Well-documented, stable API.
- Bindings in several programming languages.
- Shell (nbdsh) for command line and scripting.
- Copying tool (nbdcopy) for high performance copying and streaming.
- Hexdump tool (nbddump) to print NBD content.
- Query tool (nbdinfo) to query NBD servers.
- FUSE support (nbdfuse) to mount NBD in the local filesystem.
- Linux ublk support (nbdublk) to create the userspace block device.


%package devel
Summary:        Development headers for %{name}
Requires:       %{name} = %{version}-%{release}


%description devel
This package contains development headers for %{name}.


%package -n python3-%{name}
Summary:        Python 3 bindings for %{name}
Requires:       %{name} = %{version}-%{release}
%global __provides_exclude_from ^%{python3_sitearch}/lib.*\\.so


%description -n python3-%{name}
python3-%{name} contains Python 3 bindings for %{name}.


%package -n nbdfuse
Summary:        FUSE support for %{name}
Requires:       %{name} = %{version}-%{release}
Recommends:     fuse3


%description -n nbdfuse
This package contains FUSE support for %{name}.


%package bash-completion
Summary:       Bash tab-completion for %{name}
BuildArch:     noarch
Requires:      bash-completion >= 2.0
Requires:      %{name} = %{version}-%{release}


%description bash-completion
Install this package if you want intelligent bash tab-completion
for %{name}.

%if %{with ocaml}
%package -n ocaml-%{name}
Summary:        OCaml language bindings for %{name}
Requires:       %{name} = %{version}-%{release}


%description -n ocaml-%{name}
This package contains OCaml language bindings for %{name}.


%package -n ocaml-%{name}-devel
Summary:        OCaml language development package for %{name}
Requires:       ocaml-%{name} = %{version}-%{release}


%description -n ocaml-%{name}-devel
This package contains OCaml language development package for
%{name}.  Install this if you want to compile OCaml software which
uses %{name}.
%endif


%prep
%autosetup -p1


%build
%configure \
    --disable-static \
    --with-tls-priority=@LIBNBD,SYSTEM \
    PYTHON=%{__python3} \
    --enable-python \
%if %{without ocaml}
    --disable-ocaml \
%endif
    --enable-fuse \
    --disable-golang \
    --disable-rust

%make_build


%install
%make_install

find %{buildroot} -name '*.la' -delete

rm %{buildroot}%{_mandir}/man3/libnbd-golang.3*
rm %{buildroot}%{_datadir}/bash-completion/completions/nbdublk


%check
make -C tests connect-tcp6 ||:

%make_build check || exit 1


%files
%doc README.md
%license COPYING.LIB
%{_bindir}/nbdcopy
%{_bindir}/nbddump
%{_bindir}/nbdinfo
%{_libdir}/libnbd.so.*
%{_mandir}/man1/nbdcopy.1*
%{_mandir}/man1/nbddump.1*
%{_mandir}/man1/nbdinfo.1*


%files devel
%doc TODO examples/*.c
%license examples/LICENSE-FOR-EXAMPLES
%{_includedir}/libnbd.h
%{_libdir}/libnbd.so
%{_libdir}/pkgconfig/libnbd.pc
%{_mandir}/man3/libnbd.3*
%{_mandir}/man1/libnbd-release-notes-1.*.1*
%{_mandir}/man3/libnbd-security.3*
%{_mandir}/man3/nbd_*.3*


%files -n python3-%{name}
%{python3_sitearch}/libnbdmod*.so
%{python3_sitearch}/nbd.py
%{python3_sitearch}/nbdsh.py
%{python3_sitearch}/__pycache__/nbd*.py*
%{_bindir}/nbdsh
%{_mandir}/man1/nbdsh.1*


%files -n nbdfuse
%{_bindir}/nbdfuse
%{_mandir}/man1/nbdfuse.1*


%files bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/nbdcopy
%{_datadir}/bash-completion/completions/nbddump
%{_datadir}/bash-completion/completions/nbdfuse
%{_datadir}/bash-completion/completions/nbdinfo
%{_datadir}/bash-completion/completions/nbdsh

%if %{with ocaml}
%files -n ocaml-%{name}
%dir %{_libdir}/ocaml/nbd
%{_libdir}/ocaml/nbd/META
%{_libdir}/ocaml/nbd/*.cma
%{_libdir}/ocaml/nbd/*.cmi
%{_libdir}/ocaml/stublibs/dllmlnbd.so
%{_libdir}/ocaml/stublibs/dllmlnbd.so.owner


%files -n ocaml-%{name}-devel
%license ocaml/examples/LICENSE-FOR-EXAMPLES
%doc ocaml/examples/*.ml
%{_libdir}/ocaml/nbd/*.a
%{_libdir}/ocaml/nbd/*.cmxa
%{_libdir}/ocaml/nbd/*.cmx
%{_libdir}/ocaml/nbd/*.mli
%{_mandir}/man3/libnbd-ocaml.3*
%{_mandir}/man3/NBD.3*
%{_mandir}/man3/NBD.*.3*
%endif


%changelog
* Wed Nov 08 2023 jackeyji <jackeyji@tencent.com> - 1.17.3-4
- fix CVE-2023-5215

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.17.3-3
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.17.3-2
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Aug 23 2023 Wang Guodong <gordonwwang@tencent.com> - 1.17.3-1
- Upgrade to version 1.17.3

* Tue Aug 08 2023 cunshunxia <cunshunxia@tencent.com> - 1.15.7-5
- Rebuilt for ocaml-findlib 1.9.6

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.15.7-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.15.7-3
- Rebuilt for OpenCloudOS Stream 23

* Fri Mar 31 2023 cunshunxia <cunshunxia@tencent.com> - 1.15.7-2
- enable ocaml.

* Fri Nov 25 2022 cunshunxia <cunshunxia@tencent.com> - 1.15.7-1
- initial build
